Classification
==============

.. currentmodule:: wwt_data_formats.enums

.. autoclass:: Classification
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Classification.ASTERISM
      ~Classification.BLACKHOLE
      ~Classification.CLUSTER_OF_GALAXIES
      ~Classification.CONSTELLATION
      ~Classification.DARK_NEBULA
      ~Classification.DOUBLE_STAR
      ~Classification.ELLIPTICAL_GALAXY
      ~Classification.EMISSION_NEBULA
      ~Classification.GALACTIC
      ~Classification.GALAXY
      ~Classification.GIANT_MOLECULAR_CLOUD
      ~Classification.GLOBULAR_CLUSTER
      ~Classification.INTERSTELLAR_DUST
      ~Classification.IRREGULAR_GALAXY
      ~Classification.KNOT
      ~Classification.MULTIPLE_STARS
      ~Classification.NEBULA
      ~Classification.NEBULAE
      ~Classification.NEBULOUS_CLUSTER
      ~Classification.NEUTRON_STAR
      ~Classification.OPEN_CLUSTER
      ~Classification.OTHER
      ~Classification.OTHER_NGC
      ~Classification.PLANETARY_NEBULA
      ~Classification.PLATE_DEFECT
      ~Classification.QUASAR
      ~Classification.REFLECTION_NEBULA
      ~Classification.SOLARS_YSTEM
      ~Classification.SPIRAL_GALAXY
      ~Classification.STAR
      ~Classification.STELLAR
      ~Classification.STELLAR_GROUPINGS
      ~Classification.SUPERNOVA
      ~Classification.SUPERNOVA_REMNANT
      ~Classification.UNFILTERED
      ~Classification.UNIDENTIFIED
      ~Classification.UNSPECIFIED

   .. rubric:: Attributes Documentation

   .. autoattribute:: ASTERISM
   .. autoattribute:: BLACKHOLE
   .. autoattribute:: CLUSTER_OF_GALAXIES
   .. autoattribute:: CONSTELLATION
   .. autoattribute:: DARK_NEBULA
   .. autoattribute:: DOUBLE_STAR
   .. autoattribute:: ELLIPTICAL_GALAXY
   .. autoattribute:: EMISSION_NEBULA
   .. autoattribute:: GALACTIC
   .. autoattribute:: GALAXY
   .. autoattribute:: GIANT_MOLECULAR_CLOUD
   .. autoattribute:: GLOBULAR_CLUSTER
   .. autoattribute:: INTERSTELLAR_DUST
   .. autoattribute:: IRREGULAR_GALAXY
   .. autoattribute:: KNOT
   .. autoattribute:: MULTIPLE_STARS
   .. autoattribute:: NEBULA
   .. autoattribute:: NEBULAE
   .. autoattribute:: NEBULOUS_CLUSTER
   .. autoattribute:: NEUTRON_STAR
   .. autoattribute:: OPEN_CLUSTER
   .. autoattribute:: OTHER
   .. autoattribute:: OTHER_NGC
   .. autoattribute:: PLANETARY_NEBULA
   .. autoattribute:: PLATE_DEFECT
   .. autoattribute:: QUASAR
   .. autoattribute:: REFLECTION_NEBULA
   .. autoattribute:: SOLARS_YSTEM
   .. autoattribute:: SPIRAL_GALAXY
   .. autoattribute:: STAR
   .. autoattribute:: STELLAR
   .. autoattribute:: STELLAR_GROUPINGS
   .. autoattribute:: SUPERNOVA
   .. autoattribute:: SUPERNOVA_REMNANT
   .. autoattribute:: UNFILTERED
   .. autoattribute:: UNIDENTIFIED
   .. autoattribute:: UNSPECIFIED
